/* 
   Support code to drive the USBMicro USB4xx I/O devices.

   Makes use of libusb to do USB specific pieces.

   Code isn't meant to be exhaustive and has only had basic testing
   but you should get the idea.  If you add any of the missing
   functions in please send me a patch :)

   Loosely based on sample code provided by USBMicro which we were
   told could be used any way we liked, including as part of a GPL'd
   package.

   (C) 2008,2009 Hugh Blemings, hugh@blemings.org

   Licensed under the GNU Public Licence V3

*/



#include <usb.h>

#define USBMICRO_VENDOR_ID  0x0DE7
/* U401 and U402 Have same vendor ID */
#define USBMICRO_4XX_PRODUCT_ID 0x0191

/* Some error codes */
#define USB4XX_CANT_SEND	-1
#define USB4XX_CANT_READ	-2

#ifndef u8
#define u8 unsigned char
#endif

/* Externally visible functions */

struct usb_dev_handle	*usb4xx_init(void);
void	usb4xx_close(usb_dev_handle *handle);

int	usb4xx_init_ports(usb_dev_handle *handle);
int	usb4xx_write_a(usb_dev_handle *handle, u8 data);
int	usb4xx_write_b(usb_dev_handle *handle, u8 data);
int	usb4xx_write_a_bit(usb_dev_handle *handle, u8 and_term, u8 or_term);
int	usb4xx_write_b_bit(usb_dev_handle *handle, u8 and_term, u8 or_term);
int	usb4xx_read_a(usb_dev_handle *handle);
int	usb4xx_read_b(usb_dev_handle *handle);
/* Missing: SetBit - 0x07 */
/* Missing: ResetBit - 0x08 */
int	usb4xx_direction_a_bit(usb_dev_handle *handle, u8 dir0, u8 dir1);
int	usb4xx_direction_b_bit(usb_dev_handle *handle, u8 dir0, u8 dir1);
/* Missing: Strobe Write - 0x0b */
/* Missing: Strobe Read - 0x0c */
/* Missing: Multi-Byte StrobeWrite - 0x0d */
/* Missing: Multi-Byte StrobeWrite - 0x0e */
/* Unused: 0x0f */
/* Missing: Init LCD - 0x10 */
/* Missing: Write LCD Command- 0x11 */
/* Missing: Write LCD Data - 0x12 */
/* Unused: 0x13 */
int	usb4xx_init_spi(usb_dev_handle *handle, u8 data);
int	usb4xx_spi_master(usb_dev_handle *handle, int num_bytes, u8 *data);
int	usb4xx_spi_slave_write(usb_dev_handle *handle, int index, u8 *data);
int	usb4xx_spi_slave_read(usb_dev_handle *handle, int *count, u8 *data);

